@@ -35,19 +35,19 @@ checkAutoconf()
     AUTOCONF="`$WHICH autoconf-2.52`"
   elif test -x "`$WHICH autoconf2.50`" ; then
     AUTOCONF="`$WHICH autoconf2.50`"
-  elif test -x "`$WHICH autoconf`";then
-   AUTOCONF="`$WHICH autoconf`"
+  elif test -x "`$WHICH autoconf`" ; then
+    AUTOCONF="`$WHICH autoconf`"
   fi
 }
 
 checkAutoheader()
 {
   if test -x "`$WHICH autoheader253`";then
-   AUTOCONF="`$WHICH autoheader253`"
+   AUTOHEADER="`$WHICH autoheader253`"
   elif test -x "`$WHICH autoheader258`" ; then
-    AUTOCONF="`$WHICH autoheader258`"
+    AUTOHEADER="`$WHICH autoheader258`"
   elif test -x "`$WHICH autoheader259`" ; then
-    AUTOCONF="`$WHICH autoheader259`"
+    AUTOHEADER="`$WHICH autoheader259`"
   elif test -x "`$WHICH autoheader-2.5x`" ; then
     AUTOHEADER="`$WHICH autoheader-2.5x`"
     AUTOM4TE="`$WHICH autom4te-2.5x`"
@@ -109,6 +109,7 @@ $AUTOMAKE -ac  || echo "Can not find automake on your system. Install it"
 # >/dev/null 2>/dev/null
 echo "...Done"
 echo  "Execing $AUTOCONF"
+echo $AUTOCONF
 $AUTOCONF || echo "Can not find autoconf on your system. Install it"
 #>/dev/null 2>/dev/null
 echo "...Done"
