@@ -17,7 +17,7 @@ int maxreceiver;
 int maxtotal;
 int maxbyte;
 
-void removespaces(char *);
+int removespaces(char *, int);
 void loadconfig(char *);
 void readconfig(char *);
 
