@@ -9,6 +9,7 @@
 #include "LangCfg.h"
 #include "loadconfig.h"
 #include "Store.h"
+#include "config.h" /* to use variables created by configure */
 
 extern char langfile[VALSIZE]; 
 extern char logtype[VALSIZE]; 
@@ -50,7 +51,7 @@ int main(int argc, char **argv)
 	general.from_byte = 0;
 	
 	if (f == 0) 
-		readconfig("/usr/local/etc/isoqlog.conf");
+		readconfig(CONFIGFILE); /* CONFIGFILE variable is defined in config.h */
 	else 
 		readconfig(isoqlogconf);
 	loadLang(langfile);
